package cn.com.infosec.mobile.android.util;

import android.content.Context;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.net.NetworkInfo.State;
import android.preference.PreferenceManager;
import android.telephony.TelephonyManager;
import android.text.TextUtils;
import java.io.File;
import java.math.BigInteger;
import java.util.UUID;

public class Util {
   private static String CACHED_DEVICE_IDENTIFIER;

   public static String getIdentifier(Context context) {
      String var1;
      if (TextUtils.isEmpty(var1 = PreferenceManager.getDefaultSharedPreferences(context).getString(CACHED_DEVICE_IDENTIFIER, (String)null))) {
         if (TextUtils.isEmpty(var1 = "A01" + UUID.randomUUID().toString().replace("-", ""))) {
            throw new RuntimeException("Can not get device identifier, something is wrong with this device!");
         }

         PreferenceManager.getDefaultSharedPreferences(context).edit().putString(CACHED_DEVICE_IDENTIFIER, var1).apply();
      }

      return var1;
   }

   public static String getNetWorkType(Context context) {
      NetworkInfo var1;
      NetworkInfo.State var2;
      if ((var1 = ((ConnectivityManager)context.getSystemService("connectivity")).getNetworkInfo(1)) == null || (var2 = var1.getState()) == null || var2 != State.CONNECTED && var2 != State.CONNECTING) {
         switch (((TelephonyManager)context.getSystemService("phone")).getNetworkType()) {
            case 1:
            case 2:
            case 4:
            case 7:
            case 11:
               return "NETWORK_2G";
            case 3:
            case 5:
            case 6:
            case 8:
            case 9:
            case 10:
            case 12:
            case 14:
            case 15:
               return "NETWORK_3G";
            case 13:
               return "NETWORK_4G";
            default:
               return "NETWORK_MOBILE";
         }
      } else {
         return "NETWORK_WIFI";
      }
   }

   public static String getAuthToken() {
      return genTimeOTP("2017infosecAND".getBytes(), System.currentTimeMillis() / 60000L, (byte[])null, 8);
   }

   public static String genTimeOTP(byte[] seed, long timeFactor, byte[] eventFactor, int returnDigits) {
      byte[] var5 = new byte[8];

      for(int var6 = 7; var6 >= 0; --var6) {
         var5[var6] = (byte)((int)(timeFactor & 255L));
         timeFactor >>= 8;
      }

      String timeFactor1;
      for(timeFactor1 = Hex.byte2Hex(var5); timeFactor1.length() < 16; timeFactor1 = "0" + timeFactor1) {
      }

      String seed1 = Hex.byte2Hex(seed);
      String var2 = "";
      if (eventFactor != null) {
         var2 = Hex.byte2Hex(eventFactor);
      }

      for(timeFactor1 = timeFactor1 + var2; timeFactor1.length() < 32; timeFactor1 = timeFactor1 + "0") {
      }

      seed = Hex.hex2Byte(seed1 + timeFactor1);
      SM3Digest var10000 = new SM3Digest();
      var10000.update(seed);
      var10000.digest(seed = new byte[32]);
      BigInteger timeFactor2 = BigInteger.ZERO;

      for(int var10 = 0; var10 < 8; ++var10) {
         byte[] timeFactor3 = new byte[4];
         System.arraycopy(seed, var10 * 4, timeFactor3, 0, 4);
         timeFactor2 = timeFactor2.add(new BigInteger(1, timeFactor3));
      }

      for(seed1 = String.valueOf(timeFactor2.mod(BigInteger.valueOf(2L).pow(32)).mod(BigInteger.valueOf(10L).pow(returnDigits)).intValue()); seed1.length() < returnDigits; seed1 = "0" + seed1) {
      }

      return seed1;
   }

   public static boolean deleteFolder(File folder) {
      File[] var1;
      if (folder.isDirectory() && (var1 = folder.listFiles()) != null) {
         int var2 = var1.length;

         for(int var3 = 0; var3 < var2; ++var3) {
            deleteFolder(var1[var3]);
         }
      }

      return folder.delete();
   }
}
